@@ -344,6 +344,9 @@ def call_method(metaObject, args, unknown_args, colorPrint):
                 check_res = check_result_msg(method_result, view, check_res,
                                              args)
                 if not check_res:
+                    #override return code
+                    if method_result[0].type == "sysinstalled":
+                        metaObject.method_status = ProcessStatus.SystemAlreadyInstalled
                     return None
                 else:
                     param_object = get_param_pwd(check_res, view,
