@@ -39,7 +39,7 @@ class VariableClCorePkgName(Variable):
     Package name
     """
     type = "choiceedit"
-    opt = ["--pkg-name"]
+    opt = ["-n", "--pkg-name"]
     metavalue = "PN"
     untrusted = True
 
@@ -255,7 +255,7 @@ class VariableClCorePkgCategory(Variable):
     Package category
     """
     type = "choiceedit"
-    opt = ["--pkg-category"]
+    opt = ["-c", "--pkg-category"]
     metavalue = "CATEGORY"
     untrusted = True
     pkgCategories = {}
